﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;
using CinemaWin.Iqiyi.Model.Cinema;
using CinemaWin.Iqiyi.Request.Cinema;
using CinemaWin.Iqiyi.Response.Cinema;
using iqiyiWin.Constant;
using iqiyiWin.Model;
using iqiyiWin.Request;
using iqiyiWin.Request.Cinema;
using iqiyiWin.Response;
using iqiyiWin.Response.Cinema.CinemaItem;
using iqiyiWin.Response.Cinema.Citites;
using iqiyiWin.Util;
using Newtonsoft.Json;

namespace iqiyiWin.Api
{
    public class Cinema
    {
        public static List<IqiyiH5City> GetCities()
        {
            var request = new IqiyiH5BaseRequest();

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_CITIES + queryText, queryList);

            var response = JsonConvert.DeserializeObject<CityListResponse>(responseStr);

            var cityList = new List<IqiyiH5City>();

            if (response != null && response.Code == "A00000")
            {
                foreach (var cItem in response.Data.Cities)
                {
                    foreach (var item in cItem.Value)
                    {
                        cityList.Add(item);
                    }
                }
                 //UILogUtils.Info($"爱奇艺票务 【获取城市列表】成功；");
                return cityList;
            }
            else
            {
                //UILogUtils.Error($"爱奇艺票务 【获取城市列表】失败:  {(response == null ? responseStr : response.Msg)}");
                return cityList;
            }
        }
        public static List<IqiyiCinema> GetCinemaList(IqiyiH5City city, int pageIndex = 0)
        {
            var request = new IqiyiH5GetCinemaRequest()
            {
                CityId = city.CityId.ToString(),
                Page = pageIndex.ToString()
            };

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_CINEMA_LIST + queryText, queryList);

            var response = JsonConvert.DeserializeObject<CinemaResponse>(responseStr);

            var cinemaList = new List<IqiyiCinema>();

            if (response != null && response.Code == "A00000")
            {

                foreach (var item in response.Data.Cinemas)
                {
                    cinemaList.Add(item);
                }
                if (response.HasNext)
                {
                    var nextCinemaList =GetCinemaList(city, pageIndex + 1);
                    cinemaList.AddRange(nextCinemaList);
                }
                //UILogUtils.Info($"爱奇艺票务 【获取影院列表】成功；");
                return cinemaList;
            }
            else
            {
                //UILogUtils.Error($"爱奇艺票务 【获取影院列表】失败:  {(response == null ? responseStr : response.Msg)}");
                return cinemaList;
            }
        }
        public static List<IqiyiH5City> getHostCities()
        {
            var request = new IqiyiH5BaseRequest();

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_CITIES + queryText, queryList);

            var response = JsonConvert.DeserializeObject<CityListResponse>(responseStr);

            var cityList = new List<IqiyiH5City>();

            if (response != null && response.Code == "A00000")
            {
                cityList = response.Data.HotCities;
                return cityList;
            }
            else
            {
                return cityList;
            }
        }
        /// <summary>
        /// 获取影院列表
        /// </summary>
        /// <param name="iqiyiH5Account">账号</param>
        /// <param name="cityId">城市id</param>
        /// <returns></returns>
        public static List<IqiyiH5Cinema> GetCinemaList(string cityId)
        {
            var request = new IqiyiH5GetCinemaListRequest()
            {
                CityId = cityId
            };

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.H5_API_GET_CINEMAS + queryText, new Dictionary<string, string>());

            var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<IqiyiH5CinemasResponse>>(responseStr);

            if (response != null && response.Success)
            {
                return response.Data.Cinemas;
            }
            else
            {
                return new List<IqiyiH5Cinema>();
            }


        }
        /// <summary>
        /// 获取电影列表
        /// </summary>
        /// <param name="iqiyiH5Account">账号</param>
        /// <param name="cinemaId">影院id</param>
        /// <returns></returns>
        public static List<IqiyiH5Movie> GetMovieList(string cityId, string cinemaId)
        {
            var request = new IqiyiH5GetMovieListRequest()
            {
                CinemaId = cinemaId,
            };

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.H5_API_GET_MOVIES + queryText, new Dictionary<string, string>());

            UILogUtils.Debug("爱奇艺H5 【获取电影列表】响应:" + responseStr);

            var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<IqiyiH5MoviesResponse>>(responseStr);

            if (response != null && response.Success)
            {
                return response.Data.CinemaInfo.Movies;
            }
            else
            {
                //UILogUtils.Error("爱奇艺H5 【获取电影列表】失败:" + (response == null ? responseStr : response.Msg));
                return new List<IqiyiH5Movie>();
            }
        }
        /// <summary>
        /// 获取场次座位信息
        /// </summary>
        /// <param name="iqiyiH5Account">账号</param>
        /// <param name="cityId">城市id</param>
        /// <param name="cinemaId">影院id</param>
        /// <param name="movieId">电影id</param>
        /// <param name="sessionId">场次id</param>
        public static List<IqiyiH5Seat> GetSeatMap(string cityId, string cinemaId, string movieId ,string sessionId)
        {
            var request = new IqiyiH5GetSeatMapRequest()
            {
                CityId = cityId,
                CinemaId = cinemaId,
                MovieId = movieId,
                SessionId = sessionId,
            };

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.H5_API_GET_SEAT_MAP +  queryText, new Dictionary<string, string>());

            var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<IqiyiH5SeatMapResponse>>(responseStr);

            var seatList = new List<IqiyiH5Seat>();

            if (response != null && response.Success)
            {
                foreach (var row in response.Data.Seats)
                {
                    foreach (var item in row.Value)
                    {
                        if (item.Aid != "")
                        {
                            item.Price = response.Data.AreaPrice[item.Aid];
                            seatList.Add(item);
                        }
                        else if (item.PartnerSeatId != "")
                        {
                            item.Price = response.Data.Price;
                            seatList.Add(item);
                        }
                    }
                }

                return seatList;
            }
            else
            {
                return seatList;
            }
        }
    }
}
