﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;
using CinemaWin.Iqiyi.Api;
using CinemaWin.Iqiyi.Model.Cinema;
using iqiyiWin.Constant;
using iqiyiWin.Model;
using iqiyiWin.Request.FilmTask;
using iqiyiWin.Response.Task.TaskList;
using iqiyiWin.Util;
using Newtonsoft.Json;

namespace iqiyiWin.Api
{
    public class FilmTask
    {
        private static Random random = new Random();
        /// <summary>
        /// 获取新手任务状态
        /// </summary>
        /// <param name="iqiyiAccount"></param>
        public static List<IqiyiTask> GetTaskList(IqiyiAccount iqiyiAccount)
        {
            var request = new GetTaskListRequest()
            {
                Ck = iqiyiAccount.Cookie
            };
            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_TASK_LIST + queryText, queryList);
            
            var response = JsonConvert.DeserializeObject<GetTaskListResponse>(responseStr);

            var tasks = new List<IqiyiTask>();

            if (response != null && response.Code == "A00000")
            {
                tasks = response.Data.Task;
                //UILogUtils.Info($"爱奇艺票务 【获取新手任务状态】成功；");
                return tasks;
            }
            else
            {
                //UILogUtils.Error($"爱奇艺票务 【获取新手任务状态】失败:  {(response == null ? responseStr : response.Msg)}");
                return tasks;
            }
        }
        /// <summary>
        /// 标记想看电影票
        /// </summary>
        /// <param name="iqiyiAccount"></param>
        /// <returns></returns>
        public static IqiyiH5TaskResult SignWaitShowFilm(IqiyiAccount iqiyiAccount)
        {
            var result = new IqiyiH5TaskResult()
            {
                Status = true,
                Message = ""
            };

            var hotCitites = App.Instance.IqiyiHotCitites;

            var cityId = hotCitites[random.Next(0, hotCitites.Count)].CityId;

            var waitShowFilms = City4Film.GetWaitShowFileList(iqiyiAccount, cityId);

            if(waitShowFilms == null || waitShowFilms.Count == 0)
            {
                result.Status = false;
                result.Message = "获取等待上映列表失败";
                return result;
            }

            var movieId = waitShowFilms[random.Next(0, waitShowFilms.Count)].MovieId;

            result = User.WantLookMoive(iqiyiAccount, movieId);

            return result;
        }
        public static IqiyiH5TaskResult FirstCreatedOrder(IqiyiAccount iqiyiAccount)
        {
            // 获取城市信息
            var hotCitites = App.Instance.IqiyiHotCitites;
            var cityId = hotCitites[random.Next(0, hotCitites.Count)].CityId;

            // 获取影院信息
            var cinemas = Cinema.GetCinemaList(cityId);
            if(cinemas ==null || cinemas.Count == 0)
            {
                return new IqiyiH5TaskResult() {
                    Status= false,
                    Message = "获取列表失败"
                };
            }
            var cinemaId = cinemas[random.Next(0,cinemas.Count)].CinemaId;

            // 获取电影信息
            var movies = Cinema.GetMovieList(cityId,cinemaId);
            if (movies == null || movies.Count == 0)
            {
                return new IqiyiH5TaskResult()
                {
                    Status = false,
                    Message = "获取影院电影列表失败"
                };
            }
            var movieId = movies[0].MovieId;

            // 获取场次信息
            var sessions = movies[0].Sessions[random.Next(0, movies[0].Sessions.Count)].Value;
            if (sessions == null || sessions.Count == 0)
            {
                return new IqiyiH5TaskResult()
                {
                    Status = false,
                    Message = "获取场次列表失败"
                };
            }
            var session = sessions[random.Next(0, sessions.Count)];

            // 获取座位信息
            var seats = Cinema.GetSeatMap(cityId, cinemaId, movieId, session.SessionId);
            if (seats == null || seats.Count == 0)
            {
                return new IqiyiH5TaskResult()
                {
                    Status = false,
                    Message = "获取座位列表失败"
                };
            }
            var selectSeats = new List<IqiyiH5Seat>();
            var seatIndex = 0;
            do
            {
                var seat = seats[seatIndex];
                if(seat.Status == "OK")
                {
                    selectSeats.Add(seat);
                }
                seatIndex++;
                if(seatIndex > seats.Count-1)
                {
                    return new IqiyiH5TaskResult()
                    {
                        Status = false,
                        Message = "该场次没有空位"
                    };
                }
            } while (selectSeats.Count == 0);

            // 创建订单
            var orderId = IqiyiH5OrderApi.CreateOrder(new IqiyiH5CreateOrder()
            {
                IqiyiAccount = iqiyiAccount,
                MovieId = movieId,
                Session = session,
                Seats = selectSeats
            });
            if(orderId.Length == 0)
            {
                return new IqiyiH5TaskResult()
                {
                    Status = false,
                    Message = "创建订单失败"
                }; 
            }
            return new IqiyiH5TaskResult();
        }
    }
}
