﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;
using CinemaWin.Iqiyi.Request;
using CinemaWin.Iqiyi.Request.Order;
using CinemaWin.Iqiyi.Response;
using CinemaWin.Iqiyi.Response.Order;
using Newtonsoft.Json;
using iqiyiWin.Util;
using iqiyiWin.Api;
using iqiyiWin.Response;
using iqiyiWin.Model;
using iqiyiWin.Constant;

namespace CinemaWin.Iqiyi.Api
{
    public class IqiyiH5OrderApi
    {
        /// <summary>
        /// 创建订单
        /// </summary>
        /// <param name="iqiyiH5Account">账号</param>
        /// <param name="movieIds">电影id</param>
        /// <param name="sessionId">场次id</param>
        /// <param name="seatInfo">座位信息</param>
        /// <param name="partnerId">?partnerId</param>
        /// <param name="seqNo">场次id</param>
        /// <param name="seatNum">座位数</param>
        /// <param name="seatId">座位id</param>
        /// <param name="areaId">区域id</param>
        /// <returns></returns>
        public static string CreateOrder(IqiyiH5CreateOrder createdOrderData)
        {
            // 账号
            //var iqiyiH5Account = workUnit.CinemaAccounts[orderIndex];
            var iqiyiH5Account = createdOrderData.IqiyiAccount;
            // 拆开的座位
            //var separateSeat = workUnit.SeparateSeat[orderIndex];
            var seats = createdOrderData.Seats;
            /// 电影id
            //var movieIds = workUnit.ShowItem.MovieId;
            var movieIds = createdOrderData.MovieId;
            /// sessionId
            //var sessionId = workUnit.ShowItem.PartnerSessionId;
            //SessionId = session.SessionId,
            //    PartnerId = session.PartnerId,
            //    SeqNo = session.PartnerSessionId,
            //    PartnerSessionId = session.PartnerSessionId,
            var sessionId = createdOrderData.Session.SessionId;
            /// {row}:{column}|{row}:{column}
            var seatInfoList = new List<string>();
            /// ?partnerId
            //var partnerId = workUnit.ShowItem.PartnerId;
            var partnerId = createdOrderData.Session.PartnerId;
            /// sessionId
            //var seqNo = workUnit.ShowItem.PartnerSessionId;
            var seqNo = createdOrderData.Session.PartnerSessionId;
            /// 选座数量
            var seatNum = seats.Count;
            /// partnerSeatId,partnerSeatId
            var seatIdList = new List<string>();
            /// ?aid
            var areaId = "";

            foreach (var seat in seats)
            {
                seatInfoList.Add($"{seat.Row}:{seat.Column}");
                seatIdList.Add($"{seat.PartnerSeatId}");
                areaId = seat.Aid;
            }

            var request = new IqiyiH5CreateOrderRequest()
            {
                Ck = iqiyiH5Account.Cookie,
                MovieIds = movieIds,
                SessionId = sessionId,
                SeatInfo = string.Join("|", seatInfoList.ToArray()),
                PartnerId = partnerId,
                SeqNo = seqNo,
                SeatNum = seatNum.ToString(),
                SeatId = string.Join(",", seatIdList.ToArray()),
                AreaId = areaId
            };

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));
            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var cookieContainer = new CookieContainer();
            var cookieItem = new Cookie();
            cookieItem.Name = "P00001";
            cookieItem.Value = iqiyiH5Account.Cookie;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);

            var responseStr = HttpUtils.DoPost(cookieContainer, Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.H5_API_CREATE_ORDER, UrlUtils.BuildQueryStringUrl(queryList).Substring(1));

            var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<IqiyiH5CreateOrderResponse>>(responseStr);

            if (response != null && response.Success)
            {
                return response.Data.OrderId;
            }
            else
            {
                return "";
            }
        }
        /// <summary>
        /// 获取确定订单详情
        /// </summary>
        /// <param name="iqiyiH5Account">账号</param>
        /// <param name="orderId">订单Id</param>
        /// <returns></returns>
        //public static IqiyiH5Order GetConfirmOrderInfo(IqiyiH5WorkUnit workUnit,int orderIndex)
        //{
        //    var iqiyiH5Account = workUnit.CinemaAccounts[orderIndex];
        //    var orderId = workUnit.CinemaAccounts[orderIndex].IQYOrderNo;
        //    var request = new IqiyiH5BaseRequest()
        //    {
        //        Ck = iqiyiH5Account.Cookie
        //    };

        //    SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));
        //    queryList.Add("orderId", orderId);
        //    queryList.Add("orderSource", "seatMap");

        //    request.Sig = IqiyiHelpUtils.GetSign(queryList);
        //    queryList["sig"] = request.Sig;
            

        //    var queryText = UrlUtils.BuildQueryStringUrl(queryList);
            
        //    var responseStr = HttpUtils.DoGet(iqiyiH5Account.CookieContainer, IqiyiDomainConstants.REFERER_DOMAIN, IqiyiDomainConstants.TICKET_IQIYI + IqiyiApiConstants.H5_API_GET_CONFIRM_ORDER_INFO + "?" + queryText, new Dictionary<string, string>());

        //    UILogUtils.Debug("爱奇艺H5 【获取电影列表】响应:" + responseStr);
            
        //    var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<IqiyiH5Order>>(responseStr);

        //    if (response != null && response.Success)
        //    {
        //        return response.Data;
        //    }
        //    else
        //    {
        //        UILogUtils.Error("爱奇艺H5 【获取电影列表】失败:" + (response == null ? responseStr : response.Msg));
        //        return null;
        //    }
        //}
        ///// <summary>
        ///// 确定订单信息
        ///// </summary>
        ///// <param name="iqiyiH5Account">账号</param>
        ///// <param name="expCard">优惠券</param>
        ///// <param name="discountType">折扣类型</param>
        ///// <param name="balanceCount">观影豆</param>
        //public static Boolean ConfirmOrder(IqiyiH5WorkUnit workUnit ,int orderIndex)
        //{
        //    var orderId = workUnit.CinemaAccounts[orderIndex].IQYOrderNo;
        //    var expCard = "";
        //    var discountType = 0;
        //    var balanceCount = workUnit.IqiyiOrders[orderIndex].BalanceInfo.BalanceCount;
        //    if (workUnit.IqiyiOrders[orderIndex].DiscountInfo.Price > 0)
        //    {
        //        expCard = workUnit.IqiyiOrders[orderIndex].DiscountInfo.DiscountId;
        //        discountType = workUnit.IqiyiOrders[orderIndex].DiscountInfo.UseType;
        //    }
        //    var iqiyiH5Account = workUnit.CinemaAccounts[orderIndex];
        //    var request = new IqiyiH5ConfirmOrderRequest()
        //    {
        //        Ck = iqiyiH5Account.Cookie,
        //        OrderId = orderId,
        //        ExpCard = expCard,
        //        DiscountType = discountType,
        //        Phone = iqiyiH5Account.MobileNo,
        //        BalanceCount = balanceCount.ToString(),
        //    };

        //    SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

        //    request.Sig = IqiyiHelpUtils.GetSign(queryList);
            
        //    var responseStr = HttpUtils.DoPost(iqiyiH5Account.CookieContainer, IqiyiDomainConstants.REFERER_DOMAIN, IqiyiDomainConstants.TICKET_IQIYI + IqiyiApiConstants.H5_API_CONFIRM_ORDER, UrlUtils.BuildQueryStringUrl(request), new Dictionary<string, string>());

        //    UILogUtils.Debug("爱奇艺H5 【确认订单】响应:" + responseStr);

        //    var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<IqiyiH5ConfirmOrderResponse>>(responseStr);

        //    if (response != null && response.Success)
        //    {
        //        UILogUtils.Info($"爱奇艺H5 【确认订单】成功。订单Id：{response.Data.OrderId}");
        //        return true;
        //    }
        //    else
        //    {
        //        UILogUtils.Error("爱奇艺H5 【确认订单】失败:" + (response == null ? responseStr : response.Msg));
        //        return false;
        //    }
        //}
        //public static string PayOrder(IqiyiH5WorkUnit workUnit,int orderIndex)
        //{
        //    var iqiyiH5Account = workUnit.CinemaAccounts[orderIndex];
        //    var orderId = iqiyiH5Account.IQYOrderNo;
        //    SortedDictionary<string, string> queryList = new SortedDictionary<string, string>() ;
        //    queryList.Add("partner_order_no", orderId);
        //    queryList.Add("partner", "piaowu");
        //    queryList.Add("version", "1.0");
        //    queryList.Add("platform", "h5");
        //    queryList.Add("pay_type", "ALIPAYWAPCREATEDIRECT");

        //    var sign = IqiyiHelpUtils.GetPaySign(queryList);
        //    queryList.Add("sign", sign);

        //    var queryText = UrlUtils.BuildQueryStringUrl(queryList);
            
        //    var responseStr = "";
        //    try
        //    {
        //        responseStr = HttpUtils.DoGet(iqiyiH5Account.CookieContainer, IqiyiDomainConstants.REFERER_CASHIER, IqiyiDomainConstants.PAY_IQIYI + IqiyiApiConstants.H5_API_PAY_ORDER + "?" + queryText, new Dictionary<string, string>(), 30 * 1000, true);
        //    }
        //    catch (Exception ex)
        //    {
        //        UILogUtils.Error(ex);
        //        return null;
        //    }
        //    UILogUtils.Debug("爱奇艺H5 【获取支付链接】响应:" + responseStr);
            
        //    if (responseStr != null && responseStr.Contains("mclient.alipay.com"))
        //    {
        //        UILogUtils.Debug("爱奇艺H5 【获取支付链接】成功:" + responseStr);
        //        return responseStr;
        //    }
        //    else
        //    {
        //        UILogUtils.Error("爱奇艺H5 【获取电影列表】失败；" + (responseStr));
        //        return null;
        //    }
        //}
        //public static IqiyiH5SimpleDraw GetOrderInfo(IqiyiH5Account cinemaAccount)
        //{
        //    var iqiyiH5Account = cinemaAccount;
        //    var orderId = cinemaAccount.IQYOrderNo;
        //    var request = new IqiyiH5BaseRequest()
        //    {
        //        Ck = iqiyiH5Account.Cookie
        //    };

        //    SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));
        //    queryList.Add("orderId", orderId);

        //    request.Sig = IqiyiHelpUtils.GetSign(queryList);
        //    queryList["sig"] = request.Sig;


        //    var queryText = UrlUtils.BuildQueryStringUrl(queryList);
            
        //    var responseStr = HttpUtils.DoGet(iqiyiH5Account.CookieContainer, IqiyiDomainConstants.REFERER_DOMAIN, IqiyiDomainConstants.TICKET_IQIYI + IqiyiApiConstants.H5_API_GET_ORDER_INFO + "?" + queryText, new Dictionary<string, string>());

        //    UILogUtils.Debug("爱奇艺H5 【获取订单详情】响应:" + responseStr);

        //    var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<IqiyiH5OrderInfoResponse>>(responseStr);

        //    var resultData = new IqiyiH5SimpleDraw();
        //    if (response != null && response.Success)
        //    {
        //        if(response.Data.OrderStatus == "1")
        //        {
        //            cinemaAccount.WorkStatus = (int)IqyiH5CinemaAccountStatusEnum.NotIssued;
        //            cinemaAccount.WorkStatusDesc = EnumsUtils.GetDescriptionByEnum(IqyiH5CinemaAccountStatusEnum.NotIssued);
        //        }
        //        else if(response.Data.OrderStatus == "2")
        //        {
        //            cinemaAccount.WorkStatus = (int)IqyiH5CinemaAccountStatusEnum.PaymentOvertime;
        //            cinemaAccount.WorkStatusDesc = EnumsUtils.GetDescriptionByEnum(IqyiH5CinemaAccountStatusEnum.PaymentOvertime);
        //        }
        //        else if (response.Data.OrderStatus == "3")
        //        {
        //            cinemaAccount.WorkStatus =(int)IqyiH5CinemaAccountStatusEnum.NoTicketIssued;
        //            cinemaAccount.WorkStatusDesc = EnumsUtils.GetDescriptionByEnum(IqyiH5CinemaAccountStatusEnum.NoTicketIssued);
        //        }
        //        else
        //        {
        //            if (response.Data.TwoDimenCode != null && response.Data.TwoDimenCode != "")
        //            {
        //                resultData.QrCode = response.Data.TwoDimenCode;
        //                resultData.Code = response.Data.TwoDimenCode.Split('|')[0];
        //                resultData.ValidCode = response.Data.TwoDimenCode.Split('|').Length > 1 ? response.Data.TwoDimenCode.Split('|')[1] : "";
        //            }
        //            else if (response.Data.MachineInfos != null && response.Data.MachineInfos.TicketId != null && response.Data.MachineInfos.Pwd != null)
        //            {
        //                resultData.Code = response.Data.MachineInfos.TicketId;
        //                resultData.ValidCode = response.Data.MachineInfos.Pwd;
        //            }
        //            else if (response.Data.MachineInfos != null && response.Data.MachineInfos.Pwd != null)
        //            {
        //                resultData.Code = response.Data.MachineInfos.Pwd;
        //            }
        //            else if (response.Data.MachineInfos != null && response.Data.MachineInfos.TwoDimenCode != null)
        //            {
        //                resultData.Code = response.Data.MachineInfos.TwoDimenCode;
        //                resultData.ValidCode = response.Data.MachineInfos.Pwd != "" ? response.Data.MachineInfos.Pwd.Replace(" ", "") : "";
        //            }
        //            else if (response.Data.MachineInfos != null && response.Data.MachineInfos.TicketId != "")
        //            {
        //                resultData.Code = response.Data.MachineInfos.TicketId.Replace(" ", "");
        //                resultData.ValidCode = response.Data.MachineInfos.Pwd != "" ? response.Data.MachineInfos.Pwd.Replace(" ", "") : "";
        //            }
        //            else
        //            {
        //                cinemaAccount.WorkStatus = (int)IqyiH5CinemaAccountStatusEnum.WaitUploadNotEnum;
        //                cinemaAccount.WorkStatusDesc = EnumsUtils.GetDescriptionByEnum(IqyiH5CinemaAccountStatusEnum.WaitUploadNotEnum);

        //            }
        //        }
        //        return resultData;
        //    }
        //    else
        //    {
        //        UILogUtils.Error("爱奇艺H5 【获取订单详情】失败:" + (response == null ? responseStr : response.Msg));
        //        return resultData;
        //    }
        //}
    }
}
