﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;
using iqiyiWin.Constant;
using iqiyiWin.Model;
using iqiyiWin.Request;
using iqiyiWin.Request.User;
using iqiyiWin.Response;
using iqiyiWin.Response.User.CouponList;
using iqiyiWin.Response.User.LockDraw;
using iqiyiWin.Response.User.MovieBean;
using iqiyiWin.Response.User.Sign;
using iqiyiWin.Util;
using Newtonsoft.Json;

namespace iqiyiWin.Api
{
    public class User
    {
        private static Random NonceRandom = new Random();
        public static CookieCollection GetSupportAreacode()
        {
            var queryList = new SortedDictionary<string, string>();
            queryList.Add("local", "1");
            queryList.Add("use_case", "1");
            queryList.Add("ptid", "02032001010000000000");
            queryList.Add("agenttype", "12");

            var cookieContainer = new CookieContainer();

            var response = HttpUtils.DoPostResult(cookieContainer, "https://m.iqiyi.com/", "https://passport.iqiyi.com" + "/apis/phone/get_support_areacode.action?smart", UrlUtils.BuildQueryStringUrl(queryList).Substring(1), null);

            return response.Cookie;

            //var response = JsonConvert.DeserializeObject<object>(responseStr);
        }
        public static string UserLogin(IqiyiAccount iqiyiAccount)
        {
            var guid = Guid.NewGuid().ToString(); 
            // 获取P00004 & QC005
            var cookieCollection = GetSupportAreacode();
            var cookieContainer = new CookieContainer();
            var QC005 = "";

            var cookieItem = new Cookie();
            foreach (var v in cookieCollection)
            {
                var ckItem = v as Cookie;
                if(ckItem.Name == "QC005")
                {
                    QC005 = ckItem.Value;
                }
                cookieItem.Name = ckItem.Name;
                cookieItem.Value = ckItem.Value;
                cookieItem.Domain = ckItem.Domain;
                cookieContainer.Add(cookieItem);
            }

            // 获取QC006
            var QC006 = IqiyiSign.GetQC006();
            var QC007 = "DIRECT";
            // 写入 QC006 & QC007
            cookieItem.Name = "QC006";
            cookieItem.Value = QC006;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);
            cookieItem.Name = "QC007";
            cookieItem.Value = QC007;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);

            var signRequst = new IqiyiH5DfpSignRequest()
            {
                Dim = IqiyiSign.GetDim(QC005, QC006, guid)
            };

            signRequst.Sig =  IqiyiSign.H5Sign(signRequst.Dim + signRequst.Plat + signRequst.Ver).ToUpper();
            SortedDictionary<string, string> signQueryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(signRequst));

            var signResponseStr = HttpUtils.DoPost(cookieContainer, "https://m.iqiyi.com/", "https://cook.iqiyi.com" + "/security/dfp_pcw/sign", UrlUtils.BuildQueryStringUrl(signQueryList).Substring(1), null, 10000);

            var signResponse = JsonConvert.DeserializeObject<SignResponse>(signResponseStr);
            if (signResponse.Code != "0")
            {
                return "";
            }
            var request = new IqiyiH5UserLoginRequest()
            {
                Email = iqiyiAccount.MobileNo,
                Passwd = IqiyiSign.Encryption(iqiyiAccount.Password),
                Dfp = signResponse.Result.Dfp
            };


            cookieItem.Name = "__uuid";
            cookieItem.Value = guid;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);

            //cookieItem.Name = "__dfp";
            //cookieItem.Value = signResponse.Result.Dfp + "@" + signResponse.Result.ExpireAt + "@" + signResponse.Result.ExpireAt;
            //cookieItem.Domain = ".iqiyi.com";
            //cookieContainer.Add(cookieItem);

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            var responseObject = HttpUtils.DoPostResult(cookieContainer, "https://m.iqiyi.com/", "https://passport.iqiyi.com" + "/apis/reglogin/login.action", UrlUtils.BuildQueryStringUrl(queryList).Substring(1), null, 10000);

            var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<object>>(responseObject.Body);

            if (response != null && response.Code == "A00000")
            {
                var resultCookies = responseObject.Cookie;
                var P00001 = "";
                foreach (var item in resultCookies)
                {
                    var ckItem = item as Cookie;
                    if(ckItem.Name == "P00001")
                    {
                        P00001 = ckItem.Value;
                        break;
                    }
                }

                return P00001;
            }
            else
            {
                // UILogUtils.Error($"爱奇艺票务 【获取观影豆】失败:  {iqiyiAccount.MobileNo} {(response == null ? responseStr : response.Msg)}");
                return response.Msg;
            }
        }
        /// <summary>
        /// 查询观影豆
        /// </summary>
        /// <param name="cookie"></param>
        /// <returns></returns>
        public static string GetMovieBean(IqiyiAccount iqiyiAccount)
        {
            var request = new IqiyiH5UserBaseRequest()
            {
                Ck = iqiyiAccount.Cookie
            };
            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));
            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var cookieContainer = new CookieContainer();
            var cookieItem = new Cookie();
            cookieItem.Name = "P00001";
            cookieItem.Value = iqiyiAccount.Cookie;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(cookieContainer, Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_MOVIE_BEAN + queryText, queryList);

            var response = JsonConvert.DeserializeObject<MovieBeanResponse>(responseStr);

            if (response != null && response.Code == "A00000")
            {
                // UILogUtils.Info($"爱奇艺票务 【获取观影豆】成功: {iqiyiAccount.MobileNo} [当前观影豆：{response.Data.BalanceCount}]");
                return response.Data.BalanceCount.ToString();
            }
            else
            {
                // UILogUtils.Error($"爱奇艺票务 【获取观影豆】失败:  {iqiyiAccount.MobileNo} {(response == null ? responseStr : response.Msg)}");
                return "-1";
            }
        }
        /// <summary>
        /// 获取优惠券
        /// </summary>
        /// <param name="iqiyiAccount"></param>
        /// <returns></returns>
        public static List<Valid> GetCouponList(IqiyiAccount iqiyiAccount)
        {

            var request = new IqiyiH5UserBaseRequest()
            {
                Ck = iqiyiAccount.Cookie
            };
            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));
            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var cookieContainer = new CookieContainer();
            var cookieItem = new Cookie();
            cookieItem.Name = "P00001";
            cookieItem.Value = iqiyiAccount.Cookie;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(cookieContainer, Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_COUPON_LIST + queryText, queryList);

            var response = JsonConvert.DeserializeObject<CouponListResponse>(responseStr);

            if (response != null && response.Code == "A00000")
            {
                var couponTextList = new List<string>();
                foreach (Valid item in response.Data.Valid)
                {
                    couponTextList.Add($"                  {item.DisplayName}-{item.DisCountStr}-{item.AvailableTips}");
                };
                // UILogUtils.Info($"爱奇艺票务 【获取优惠券数量】成功: {iqiyiAccount.MobileNo} [当前优惠券数量：{response.Data.Valid.Count}]\n{ string.Join("\n", couponTextList.ToArray())}");
                return response.Data.Valid;
            }
            else
            {
                // UILogUtils.Error($"爱奇艺票务 【获取优惠券数量】失败: {iqiyiAccount.MobileNo} {(response == null ? responseStr : response.Msg)}");
                return null;
            }
        }
        /// <summary>
        /// 签到
        /// </summary>
        /// <param name="iqiyiAccount"></param>
        /// <returns></returns>
        public static Boolean UserDoSign(IqiyiAccount iqiyiAccount)
        {
            var headers = new SortedDictionary<string, string>();

            var dfp = IqiyiVersion.Dfp();

            headers.Add("deviceId", dfp);
            headers.Add("dfp", dfp);
            headers.Add("appid", "10010");
            headers.Add("os", "14.4");
            headers.Add("format", "json");
            headers.Add("platform", "iphone");
            headers.Add("ts", DateUtils.GetTimeStampOfMilliseconds().ToString());
            headers.Add("location", "");
            headers.Add("src", "ios");
            headers.Add("version", "3.3.0");
            headers.Add("ck", iqiyiAccount.Cookie);
            headers.Add("nonce", "1248907070");
            headers.Add("bizType", "APP");
            headers.Add("_t", DateUtils.GetTimeStampOfMilliseconds().ToString());
            headers.Add("cityId", "");

            var queryText = UrlUtils.BuildQueryStringUrl(headers);

            var responseStr = HttpUtils.DoGet(Domain.TICKET_IQIYI + ApiConstant.USER_SIGN_IN + queryText, headers);

            var response = JsonConvert.DeserializeObject<CouponListResponse>(responseStr);

            if (response != null && (response.Code == "A00000" || response.Code == "A00001"))
            {
                // UILogUtils.Info($"爱奇艺票务 【签到】成功: {iqiyiAccount.MobileNo}");
                return true;
            }
            else
            {
                // UILogUtils.Error($"爱奇艺票务 【签到】失败: {iqiyiAccount.MobileNo} {(response == null ? responseStr : response.Msg)}");
                return false;
            }
        }
        /// <summary>
        /// 抽奖
        /// </summary>
        /// <param name="iqiyiAccount"></param>
        public static LockDrawResponse LockDarw(IqiyiAccount iqiyiAccount, string actCode)
        {

            var headers = new SortedDictionary<string, string>();
            var queryList = new SortedDictionary<string, string>();

            queryList.Add("actCode", actCode);
            queryList.Add("P00001", iqiyiAccount.Cookie);
            headers.Add("Origin", "https://www.iqiyi.com");

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.WWW_IQIYI, Domain.PCELL_DOMAIN + ApiConstant.LOCK_DRAW + queryText, headers);

            var response = JsonConvert.DeserializeObject<LockDrawResponse>(responseStr);

            return response;
        }
        /// <summary>
        /// 想看电影
        /// </summary>
        /// <param name="iqiyiAccount"></param>
        /// <param name="movieId"></param>
        /// <returns></returns>
        public static IqiyiH5TaskResult WantLookMoive(IqiyiAccount iqiyiAccount, string movieId)
        {
            var request = new WantLookMoiveRequest()
            {
                Ck = iqiyiAccount.Cookie,
                MovieId = movieId
            };

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));

            request.Sig = IqiyiSign.Sign(queryList);
            queryList["sig"] = request.Sig;

            var queryText = UrlUtils.BuildQueryStringUrl(queryList);

            var cookieContainer = new CookieContainer();
            var cookieItem = new Cookie();
            cookieItem.Name = "P00001";
            cookieItem.Value = iqiyiAccount.Cookie;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);

            var responseStr = HttpUtils.DoGet(cookieContainer, Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.WANT_LOOK_MOVIE + queryText, queryList);

            var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<object>>(responseStr);

            if (response != null && response.Code == "A00000")
            {
                return new IqiyiH5TaskResult();
            }
            else
            {
                return new IqiyiH5TaskResult() {
                    Status = false,
                    Message = response.Msg
                };
            }
        }
        public static IqiyiH5TaskResult ReceiveTaskNovice(IqiyiAccount iqiyiAccount, string recordId)
        {
            var request = new IqiyiH5ReceiveWaitLookRequest()
            {
                Ck = iqiyiAccount.Cookie,
                RecordId = recordId
            };

            var cookieContainer = new CookieContainer();
            var cookieItem = new Cookie();
            cookieItem.Name = "P00001";
            cookieItem.Value = iqiyiAccount.Cookie;
            cookieItem.Domain = ".iqiyi.com";
            cookieContainer.Add(cookieItem);

            SortedDictionary<string, string> queryList = JsonConvert.DeserializeObject<SortedDictionary<string, string>>(JsonConvert.SerializeObject(request));
            var responseStr = HttpUtils.DoPost(cookieContainer, "https://act.iqiyi.com/", Domain.TICKET_IQIYI + ApiConstant.RECEIVE_TASK_NOVICE, UrlUtils.BuildQueryStringUrl(queryList));

            var response = JsonConvert.DeserializeObject<IqiyiH5BaseResponse<object>>(responseStr);

            if (response != null && response.Code == "A00000")
            {
                return new IqiyiH5TaskResult();
            }
            else
            {
                return new IqiyiH5TaskResult()
                {
                    Status = false,
                    Message = response.Msg
                };
            }
        }
    }
}
